@@ -50,7 +50,7 @@ def pytest_addoption(parser):
     )
 
 
-@pytest.fixture()
+@pytest.fixture(scope='session')
 def api_key(pytestconfig) -> str:
     """Return apikey from CLI parameters."""
     return pytestconfig.getoption('apikey')
